dim ITunes
Set ITunes = Nothing
IsAdjustingVolume = false

sub ResetDisplay(IsVisible)
On error resume Next
  this.LockAllUpdates()
  dim SongTrack
  set SongTrack = this.Layers("SongTrack")
  SongTrack.Visible = IsVisible
  set StartTime = this.Layers("StartTime")
  StartTime.Visible = IsVisible
  set EndTime = this.Layers("EndTime")
  EndTime.Visible = IsVisible
  this.Refresh()
end sub

'Check for ITunes if the window exists
sub CheckForITunes()
On error resume Next
  dim SongName
  Set SongName = this.Layers("SongName")
  if (IsITunesOn) then
    SongName.Text = ""
    ShowInformation()
    SetVolumePosition(ITunes.SoundVolume)
    this.Timers.Delete("DetectITunes")
    if (ITunes.PlayerState = 1) then
      ResetSongTimer()
      ResetDisplay(True)
    end if
  else
    ResetDisplay(False)
    SongName.Text = "ITunes Not Loaded"
    SetVolumePosition(0)
    dim Timer
    Set Timer = this.Timers("DetectITunes")
    if Timer is Nothing then
      'Check For ITunes every 2 seconds
      Set Timer =  this.Timers.New("DetectITunes",2000,"CheckForITunes()",0)
      Timer.ResetTimer()
    end if
  end if
end sub

function IsITunesOn()
On error resume Next
  dim Handle
  Handle = this.UI.FindWindow("ITunes","")
  if ( Handle > 0) then
    IsITunesOn = true
  else
    IsITunesOn = false
  end if
end function

'Connect the ITune Com interface and callback events
sub ConnectITunes()
On error resume Next
  if ITunes is Nothing then
    Set ITunes = this.createobject("iTunes.Application","itune_")
  end if
end sub

'Disconnect the ITune Com interface and callback events when the user is about to close
sub DisconnectITunes()
On error resume Next
  if not(ITunes is Nothing) then
    this.DisconnectObject(iTunes)
    Set ITunes = Nothing
    dim PlayBtn
    set PlayBtn = this.Layers("PlayBtn")
    PlayBtn.src = "play.png"
    PlayBtn.dsrc = "play_pressed.png"
  end if
end sub

'Set Player Status
sub SetPlayStatus()
On error resume Next
  dim PlayBtn
  set PlayBtn = this.Layers("PlayBtn")
  if (ITunes.PlayerState = 1) then 'playing
    PlayBtn.src = "pause.png"
    PlayBtn.dsrc = "pause_pressed.png"
  else
    PlayBtn.src = "play.png"
    PlayBtn.dsrc = "play_pressed.png"
  end if

end sub

'Show the current information
sub ShowInformation()
 On error resume Next
   ConnectITunes()
    itune_OnPlayerPlayEvent(ITunes.CurrentTrack)
    SetPlayStatus()
end sub


'ITune Play
sub PlayTrack()
On error resume Next
  ConnectITunes
  if IsObject(ITunes) then
    if (ITunes.PlayerState=1) then
      ITunes.Pause()
    else
      ITunes.Play()
    end if
  end if
end sub

'ITune Next
sub NextTrack()
On error resume Next
  ConnectITunes
  if IsObject(ITunes) then
    ITunes.NextTrack()
  end if
end sub

'ITune Previous
sub PreviousTrack()
On error resume Next
  ConnectITunes
  if IsObject(ITunes) then
    ITunes.BackTrack()
  end if
end sub

'Position to set
sub SetNewTrackPosition()
On error resume Next
  dim SongTrack
  set SongTrack = this.Layers("SongTrack")
  XPos = this.GetLayerMouseXPos
  FnPos = ITunes.CurrentTrack.Finish 'Seconds
  NewPos = XPos/SongTrack.Width
  ITunes.PlayerPosition = NewPos * FnPos
end sub

sub GetSongPosition()
On error resume Next
  FnPos = ITunes.CurrentTrack.Finish 'Seconds
  Pos = ITunes.PlayerPosition
  TrackPos = Pos / FnPos
  dim SongTrack
  set SongTrack = this.Layers("SongTrack")
  SongTrack.MaskValue = TrackPos * 255
  set StartTime = this.Layers("StartTime")
  HH = Int(Pos / 60)
  MM = Pos - (HH * 60)
  HH = CStr(HH)
  if (MM < 10) then'add leading 0
    MM = "0"+CStr(MM)
  else
    MM = CStr(MM)
  end if
  StartTime.Text = HH+":"+MM
  set EndTime = this.Layers("EndTime")
  HH = Int((FnPos-Pos) / 60)
  MM = FnPos- Pos - (HH * 60)
  HH = CStr(HH)
  if (MM < 10) then 'add leading 0
    MM = "0"+CStr(MM)
  else
    MM = CStr(MM)
  end if
  EndTime.Text = "-"+HH+":"+MM

end sub

'Create the timer to get the song position.  ITunes doesn't support any event
sub ResetSongTimer()
 On error resume Next
 Dim Timer
  Set Timer = this.Timers("GetSongPosition")
  if Timer is Nothing then
    Set Timer =  this.Timers.New("GetSongPosition",800,"GetSongPosition()",0)
  end if
  Timer.ResetTimer()
end sub

sub SetNewVolume()
On error resume Next
  set VolumeBar = this.Layers("VolumeBar")
  XPos = this.GetLayerMouseXPos
  Volume = ITunes.SoundVolume
  NewPos = XPos/VolumeBar.Width
  ITunes.SoundVolume = (NewPos * 100)+1
end sub

sub SetVolumePosition(value)
On error resume Next
   if not IsAdjustingVolume then
     SetVolumePosition()
     set VolumeBtn = this.Layers("VolumeBtn")
     set VolumeBar = this.Layers("VolumeBar")
     MaxPos = VolumeBar.Width
     VolumeBtn.X = VolumeBar.X + (value / 100 * (MaxPos-5))
   end if
end sub

sub StartVolumeCapture()
On error resume Next
   set VolumeBtn = this.Layers("VolumeBtn")
   VolumeBtn.Down = true
   IsAdjustingVolume = true
   VolumeBtn.CaptureMouse()
end sub

sub StartVolumeUnCapture()
On error resume Next
   set VolumeBtn = this.Layers("VolumeBtn")
   VolumeBtn.Down = false
   IsAdjustingVolume = false
   VolumeBtn.UnCaptureMouse()
end sub

'Set Volume using the mouse position
sub SetVolumeByKnob()
On error resume Next
  if IsAdjustingVolume then
    set VolumeBar = this.Layers("VolumeBar")
    set VolumeBtn = this.Layers("VolumeBtn")
    XPos = this.GetLayerMouseXPos
    NewXPos = VolumeBtn.X + XPos - 5 ' -5 the middle of the button about
    if (NewXPos) > (VolumeBar.X + VolumeBar.Width-5) then   ' Make sure it doesn't pass the limit
      NewXPos = VolumeBar.X + VolumeBar.Width-5
    end if
    if NewXPos < VolumeBar.X then ' Make sure it doesn't pass the limit
      NewXPos = VolumeBar.X
    end if
    VolumeBtn.X = NewXPos 'Set the visual knob position
    NewPos = (VolumeBtn.X-VolumeBar.X+5) /VolumeBar.Width 'calculate the volume
    ITunes.SoundVolume = (NewPos * 100)+1
  end if
end sub

sub ToggleArt()
On error resume Next
  if not ITunes is Nothing then
    Set fso = CreateObject("Scripting.FileSystemObject")
    fso.DeleteFile(this.IO.GetTmpPath+"\ITunesArt.png")
    For Each ArtWork in ITunes.CurrentTrack.ArtWork
      ArtWork.SaveArtworkToFile(this.IO.GetTmpPath+"\ITunesArt.png")
      Exit For ' only get the first artwork
    Next
    this.LockAllUpdates()
    Set Album = this.Layers("Album")
    Album.Visible = not Album.Visible
    Set AlbumImg = this.Layers("AlbumImg")
    AlbumImg.Image = this.IO.GetTmpPath+"\ITunesArt"
    AlbumImg.Visible = not AlbumImg.Visible
    this.Refresh()
  end if
end sub

sub ShowPlayList()
On error resume Next
  if not ITunes is Nothing then
    Text = ""
    LimitCount = 0
    For Each Track in ITunes.CurrentPlaylist.Tracks
      Text = Text + Track.Name +  vbCrLf
      LimitCount = LimitCount + 1
      if LimitCount = 100 then
        Exit For
      end if
    Next
    set Scroller = this.Controls("Scroller")
    set PlayList = this.Layers("PlayList")
    PlayList.Text = text
    Scroller.ScrollBarSize = (PlayList.ImageHeight - PlayList.Height) / 10
  end if
  this.FlipTo(1)
end sub

sub FixClipRange()
On error resume Next
  set PlayList = this.Layers("PlayList")
  set Scroller = this.Controls("Scroller")
  PlayList.ClipSource = "0,"+CStr(Scroller.Value*10)+",145,"+CStr(Scroller.Value*10+PlayList.Height)
end sub

'Events for ITune below


'Volume Change
sub itune_OnSoundVolumeChangedEvent(value)
  SetVolumePosition(value)
end sub

'Track Change
sub itune_OnPlayerPlayEvent(track)
On error resume Next
  set layer = this.Layers("SongName")
  layer.text = track.Name
  SetPlayStatus()
  ResetSongTimer()
end sub

'About to close the ITunes
sub itune_OnAboutToPromptUserToQuitEvent
On error resume Next
  DisconnectITunes()
  'Check For ITunes every 2 seconds
  Dim Timer
  Set Timer =  this.Timers.New("DetectITunes",2000,"CheckForITunes()",0)
  Timer.ResetTimer()
end sub

'On Stop.
sub itune_OnPlayerStopEvent(track)
On error resume Next
  set layer = this.Layers("SongName")
  layer.text = track.Name
  SetPlayStatus()
  Dim Timer
  Set Timer = this.Timers("GetSongPosition")
  if not Timer is Nothing then
    Timer.StopTimer()
  end if

end sub


